Struct aws_sdk_devopsguru::client::fluent_builders::GetResourceCollection [−][src]
pub struct GetResourceCollection<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to GetResourceCollection.
Returns lists Amazon Web Services resources that are of the specified resource collection type. The one type of Amazon Web Services resource collection supported is Amazon Web Services CloudFormation stacks. DevOps Guru can be configured to analyze only the Amazon Web Services resources that are defined in the stacks. You can specify up to 500 Amazon Web Services CloudFormation stacks.
Implementations
impl<C, M, R> GetResourceCollection<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> GetResourceCollection<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<GetResourceCollectionOutput, SdkError<GetResourceCollectionError>> where
R::Policy: SmithyRetryPolicy<GetResourceCollectionInputOperationOutputAlias, GetResourceCollectionOutput, GetResourceCollectionError, GetResourceCollectionInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<GetResourceCollectionOutput, SdkError<GetResourceCollectionError>> where
R::Policy: SmithyRetryPolicy<GetResourceCollectionInputOperationOutputAlias, GetResourceCollectionOutput, GetResourceCollectionError, GetResourceCollectionInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The type of Amazon Web Services resource collections to return. The one valid value is
CLOUD_FORMATION for Amazon Web Services CloudFormation stacks.
The type of Amazon Web Services resource collections to return. The one valid value is
CLOUD_FORMATION for Amazon Web Services CloudFormation stacks.
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.