Struct aws_sdk_devopsguru::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for CapstoneControlPlaneService.
This client allows ergonomic access to a CapstoneControlPlaneService-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the AddNotificationChannel operation.
See AddNotificationChannel for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeAccountHealth operation.
See DescribeAccountHealth for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeAccountOverview operation.
See DescribeAccountOverview for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeAnomaly operation.
See DescribeAnomaly for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeFeedback operation.
See DescribeFeedback for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeInsight operation.
See DescribeInsight for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeOrganizationHealth operation.
See DescribeOrganizationHealth for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeOrganizationOverview operation.
See DescribeOrganizationOverview for more information about the
operation and its arguments.
pub fn describe_organization_resource_collection_health(
&self
) -> DescribeOrganizationResourceCollectionHealth<C, M, R>
pub fn describe_organization_resource_collection_health(
&self
) -> DescribeOrganizationResourceCollectionHealth<C, M, R>
Constructs a fluent builder for the DescribeOrganizationResourceCollectionHealth operation.
See DescribeOrganizationResourceCollectionHealth for more information about the
operation and its arguments.
pub fn describe_resource_collection_health(
&self
) -> DescribeResourceCollectionHealth<C, M, R>
pub fn describe_resource_collection_health(
&self
) -> DescribeResourceCollectionHealth<C, M, R>
Constructs a fluent builder for the DescribeResourceCollectionHealth operation.
See DescribeResourceCollectionHealth for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeServiceIntegration operation.
See DescribeServiceIntegration for more information about the
operation and its arguments.
Constructs a fluent builder for the GetCostEstimation operation.
See GetCostEstimation for more information about the
operation and its arguments.
Constructs a fluent builder for the GetResourceCollection operation.
See GetResourceCollection for more information about the
operation and its arguments.
Constructs a fluent builder for the ListAnomaliesForInsight operation.
See ListAnomaliesForInsight for more information about the
operation and its arguments.
Constructs a fluent builder for the ListEvents operation.
See ListEvents for more information about the
operation and its arguments.
Constructs a fluent builder for the ListInsights operation.
See ListInsights for more information about the
operation and its arguments.
Constructs a fluent builder for the ListNotificationChannels operation.
See ListNotificationChannels for more information about the
operation and its arguments.
Constructs a fluent builder for the ListOrganizationInsights operation.
See ListOrganizationInsights for more information about the
operation and its arguments.
Constructs a fluent builder for the ListRecommendations operation.
See ListRecommendations for more information about the
operation and its arguments.
Constructs a fluent builder for the PutFeedback operation.
See PutFeedback for more information about the
operation and its arguments.
Constructs a fluent builder for the RemoveNotificationChannel operation.
See RemoveNotificationChannel for more information about the
operation and its arguments.
Constructs a fluent builder for the SearchInsights operation.
See SearchInsights for more information about the
operation and its arguments.
Constructs a fluent builder for the SearchOrganizationInsights operation.
See SearchOrganizationInsights for more information about the
operation and its arguments.
Constructs a fluent builder for the StartCostEstimation operation.
See StartCostEstimation for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateResourceCollection operation.
See UpdateResourceCollection for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateServiceIntegration operation.
See UpdateServiceIntegration for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.