Struct aws_sdk_devopsguru::input::list_events_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListEventsInput
Implementations
A ListEventsFilters object used to specify which events to return.
A ListEventsFilters object used to specify which events to return.
The maximum number of results to return with a single call.
To retrieve the remaining results, make another call with the returned nextToken value.
The maximum number of results to return with a single call.
To retrieve the remaining results, make another call with the returned nextToken value.
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
The ID of the Amazon Web Services account.
The ID of the Amazon Web Services account.
Consumes the builder and constructs a ListEventsInput