Struct aws_sdk_devopsguru::input::list_recommendations_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListRecommendationsInput
Implementations
The ID of the requested insight.
The ID of the requested insight.
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
A locale that specifies the language to use for recommendations.
A locale that specifies the language to use for recommendations.
The ID of the Amazon Web Services account.
The ID of the Amazon Web Services account.
Consumes the builder and constructs a ListRecommendationsInput