Struct aws_sdk_devopsguru::input::GetCostEstimationInput [−][src]
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetCostEstimation, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetCostEstimation, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetCostEstimation>
Creates a new builder-style object to manufacture GetCostEstimationInput