Struct aws_sdk_devopsguru::input::UpdateResourceCollectionInput [−][src]
#[non_exhaustive]pub struct UpdateResourceCollectionInput {
pub action: Option<UpdateResourceCollectionAction>,
pub resource_collection: Option<UpdateResourceCollectionFilter>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: Option<UpdateResourceCollectionAction>Specifies if the resource collection in the request is added or deleted to the resource collection.
resource_collection: Option<UpdateResourceCollectionFilter>Contains information used to update a collection of AWS resources.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateResourceCollection, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateResourceCollection, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateResourceCollection>
Creates a new builder-style object to manufacture UpdateResourceCollectionInput