Struct aws_sdk_devopsguru::input::UpdateServiceIntegrationInput [−][src]
#[non_exhaustive]pub struct UpdateServiceIntegrationInput {
pub service_integration: Option<UpdateServiceIntegrationConfig>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_integration: Option<UpdateServiceIntegrationConfig> An IntegratedServiceConfig object used to specify the integrated service
you want to update, and whether you want to update it to enabled or disabled.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateServiceIntegration, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateServiceIntegration, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateServiceIntegration>
Creates a new builder-style object to manufacture UpdateServiceIntegrationInput
An IntegratedServiceConfig object used to specify the integrated service
you want to update, and whether you want to update it to enabled or disabled.