Struct aws_sdk_devopsguru::input::update_service_integration_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdateServiceIntegrationInput
Implementations
An IntegratedServiceConfig object used to specify the integrated service you want to update, and whether you
want to update it to enabled or disabled.
An IntegratedServiceConfig object used to specify the integrated service you want to update, and whether you
want to update it to enabled or disabled.
Consumes the builder and constructs a UpdateServiceIntegrationInput