Enum aws_sdk_devopsguru::model::OptInStatus [−][src]
#[non_exhaustive]
pub enum OptInStatus {
Disabled,
Enabled,
Unknown(String),
}Expand description
Specifies if DevOps Guru is enabled to create an Amazon Web Services Systems Manager OpsItem for each created insight.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Disabled
Enabled
Unknown(String)
Tuple Fields
0: StringUnknown contains new variants that have been added since this code was generated.
Implementations