Struct aws_sdk_devopsguru::model::Event [−][src]
#[non_exhaustive]pub struct Event {
pub resource_collection: Option<ResourceCollection>,
pub id: Option<String>,
pub time: Option<DateTime>,
pub event_source: Option<String>,
pub name: Option<String>,
pub data_source: Option<EventDataSource>,
pub event_class: Option<EventClass>,
pub resources: Option<Vec<EventResource>>,
}Expand description
An Amazon Web Services resource event. Amazon Web Services resource events and metrics are analyzed by DevOps Guru to find anomalous behavior and provide recommendations to improve your operational solutions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_collection: Option<ResourceCollection>A collection of Amazon Web Services resources supported by DevOps Guru. The one type of Amazon Web Services resource collection supported is Amazon Web Services CloudFormation stacks. DevOps Guru can be configured to analyze only the Amazon Web Services resources that are defined in the stacks. You can specify up to 500 Amazon Web Services CloudFormation stacks.
id: Option<String>The ID of the event.
time: Option<DateTime> A Timestamp that specifies the time the event occurred.
event_source: Option<String>The Amazon Web Services source that emitted the event.
name: Option<String>The name of the event.
data_source: Option<EventDataSource> The source, AWS_CLOUD_TRAIL or AWS_CODE_DEPLOY, where DevOps Guru
analysis found the event.
event_class: Option<EventClass>The class of the event. The class specifies what the event is related to, such as an infrastructure change, a deployment, or a schema change.
resources: Option<Vec<EventResource>> An EventResource object that contains information about the resource
that emitted the event.
Implementations
A collection of Amazon Web Services resources supported by DevOps Guru. The one type of Amazon Web Services resource collection supported is Amazon Web Services CloudFormation stacks. DevOps Guru can be configured to analyze only the Amazon Web Services resources that are defined in the stacks. You can specify up to 500 Amazon Web Services CloudFormation stacks.
A Timestamp that specifies the time the event occurred.
The Amazon Web Services source that emitted the event.
The source, AWS_CLOUD_TRAIL or AWS_CODE_DEPLOY, where DevOps Guru
analysis found the event.
The class of the event. The class specifies what the event is related to, such as an infrastructure change, a deployment, or a schema change.