Struct aws_sdk_devopsguru::model::OpsCenterIntegration [−][src]
#[non_exhaustive]pub struct OpsCenterIntegration {
pub opt_in_status: Option<OptInStatus>,
}Expand description
Information about whether DevOps Guru is configured to create an OpsItem in Amazon Web Services Systems Manager OpsCenter for each created insight.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.opt_in_status: Option<OptInStatus>Specifies if DevOps Guru is enabled to create an Amazon Web Services Systems Manager OpsItem for each created insight.
Implementations
Specifies if DevOps Guru is enabled to create an Amazon Web Services Systems Manager OpsItem for each created insight.
Creates a new builder-style object to manufacture OpsCenterIntegration