Struct aws_sdk_devopsguru::model::ProactiveOrganizationInsightSummary [−][src]
#[non_exhaustive]pub struct ProactiveOrganizationInsightSummary {
pub id: Option<String>,
pub account_id: Option<String>,
pub organizational_unit_id: Option<String>,
pub name: Option<String>,
pub severity: Option<InsightSeverity>,
pub status: Option<InsightStatus>,
pub insight_time_range: Option<InsightTimeRange>,
pub prediction_time_range: Option<PredictionTimeRange>,
pub resource_collection: Option<ResourceCollection>,
pub service_collection: Option<ServiceCollection>,
}Expand description
Details about a proactive insight. This object is returned by
DescribeInsight.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The ID of the insight summary.
account_id: Option<String>The ID of the Amazon Web Services account.
organizational_unit_id: Option<String>The ID of the organizational unit.
name: Option<String>The name of the insight summary.
severity: Option<InsightSeverity>An array of severity values used to search for insights.
status: Option<InsightStatus>An array of status values used to search for insights.
insight_time_range: Option<InsightTimeRange>A time ranged that specifies when the observed behavior in an insight started and ended.
prediction_time_range: Option<PredictionTimeRange>The time range during which anomalous behavior in a proactive anomaly or an insight is expected to occur.
resource_collection: Option<ResourceCollection>A collection of Amazon Web Services resources supported by DevOps Guru. The one type of Amazon Web Services resource collection supported is Amazon Web Services CloudFormation stacks. DevOps Guru can be configured to analyze only the Amazon Web Services resources that are defined in the stacks. You can specify up to 500 Amazon Web Services CloudFormation stacks.
service_collection: Option<ServiceCollection>A collection of the names of Amazon Web Services services.
Implementations
The ID of the Amazon Web Services account.
The ID of the organizational unit.
An array of severity values used to search for insights.
An array of status values used to search for insights.
A time ranged that specifies when the observed behavior in an insight started and ended.
The time range during which anomalous behavior in a proactive anomaly or an insight is expected to occur.
A collection of Amazon Web Services resources supported by DevOps Guru. The one type of Amazon Web Services resource collection supported is Amazon Web Services CloudFormation stacks. DevOps Guru can be configured to analyze only the Amazon Web Services resources that are defined in the stacks. You can specify up to 500 Amazon Web Services CloudFormation stacks.
A collection of the names of Amazon Web Services services.
Creates a new builder-style object to manufacture ProactiveOrganizationInsightSummary