Struct aws_sdk_devopsguru::model::RecommendationRelatedEventResource [−][src]
#[non_exhaustive]pub struct RecommendationRelatedEventResource {
pub name: Option<String>,
pub type: Option<String>,
}Expand description
Information about an AWS resource that emitted and event that is related to a recommendation in an insight.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>
The name of the resource that emitted the event. This corresponds to the Name field in an
EventResource object.
type: Option<String>
The type of the resource that emitted the event. This corresponds to the Type field in an
EventResource object.
Implementations
Creates a new builder-style object to manufacture RecommendationRelatedEventResource