Struct aws_sdk_devopsguru::model::ResourceCollectionFilter [−][src]
#[non_exhaustive]pub struct ResourceCollectionFilter {
pub cloud_formation: Option<CloudFormationCollectionFilter>,
}Expand description
Information about a filter used to specify which Amazon Web Services resources are analyzed for anomalous behavior by DevOps Guru.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cloud_formation: Option<CloudFormationCollectionFilter>Information about Amazon Web Services CloudFormation stacks. You can use up to 500 stacks to specify which Amazon Web Services resources in your account to analyze. For more information, see Stacks in the Amazon Web Services CloudFormation User Guide.
Implementations
Information about Amazon Web Services CloudFormation stacks. You can use up to 500 stacks to specify which Amazon Web Services resources in your account to analyze. For more information, see Stacks in the Amazon Web Services CloudFormation User Guide.
Creates a new builder-style object to manufacture ResourceCollectionFilter