Struct aws_sdk_devopsguru::model::SearchInsightsFilters [−][src]
#[non_exhaustive]pub struct SearchInsightsFilters {
pub severities: Option<Vec<InsightSeverity>>,
pub statuses: Option<Vec<InsightStatus>>,
pub resource_collection: Option<ResourceCollection>,
pub service_collection: Option<ServiceCollection>,
}Expand description
Specifies one or more severity values and one or more status values that are used to search for insights.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.severities: Option<Vec<InsightSeverity>>An array of severity values used to search for insights.
statuses: Option<Vec<InsightStatus>>An array of status values used to search for insights.
resource_collection: Option<ResourceCollection>A collection of Amazon Web Services resources supported by DevOps Guru. The one type of Amazon Web Services resource collection supported is Amazon Web Services CloudFormation stacks. DevOps Guru can be configured to analyze only the Amazon Web Services resources that are defined in the stacks. You can specify up to 500 Amazon Web Services CloudFormation stacks.
service_collection: Option<ServiceCollection>A collection of the names of Amazon Web Services services.
Implementations
An array of severity values used to search for insights.
An array of status values used to search for insights.
A collection of Amazon Web Services resources supported by DevOps Guru. The one type of Amazon Web Services resource collection supported is Amazon Web Services CloudFormation stacks. DevOps Guru can be configured to analyze only the Amazon Web Services resources that are defined in the stacks. You can specify up to 500 Amazon Web Services CloudFormation stacks.
A collection of the names of Amazon Web Services services.
Creates a new builder-style object to manufacture SearchInsightsFilters