Struct aws_sdk_devopsguru::model::ServiceResourceCost [−][src]
#[non_exhaustive]pub struct ServiceResourceCost {
pub type: Option<String>,
pub state: Option<CostEstimationServiceResourceState>,
pub count: i32,
pub unit_cost: f64,
pub cost: f64,
}Expand description
An object that contains information about the estimated monthly cost to analyze an Amazon Web Services resource. For more information, see Estimate your Amazon DevOps Guru costs and Amazon DevOps Guru pricing.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<String>The type of the Amazon Web Services resource.
state: Option<CostEstimationServiceResourceState>The state of the resource. The resource is ACTIVE if it produces metrics,
events, or logs within an hour, otherwise it is INACTIVE. You pay for the
number of active Amazon Web Services resource hours analyzed for each resource. Inactive resources are
not charged.
count: i32The number of active resources analyzed for this service to create a monthly cost estimate.
unit_cost: f64The price per hour to analyze the resources in the service. For more information, see Estimate your Amazon DevOps Guru costs and Amazon DevOps Guru pricing.
cost: f64The total estimated monthly cost to analyze the active resources for this resource.
Implementations
The state of the resource. The resource is ACTIVE if it produces metrics,
events, or logs within an hour, otherwise it is INACTIVE. You pay for the
number of active Amazon Web Services resource hours analyzed for each resource. Inactive resources are
not charged.
The number of active resources analyzed for this service to create a monthly cost estimate.
The price per hour to analyze the resources in the service. For more information, see Estimate your Amazon DevOps Guru costs and Amazon DevOps Guru pricing.
Creates a new builder-style object to manufacture ServiceResourceCost