Struct aws_sdk_devopsguru::model::UpdateCloudFormationCollectionFilter [−][src]
#[non_exhaustive]pub struct UpdateCloudFormationCollectionFilter {
pub stack_names: Option<Vec<String>>,
}Expand description
Contains the names of Amazon Web Services CloudFormation stacks used to update a collection of stacks. You can specify up to 500 Amazon Web Services CloudFormation stacks.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stack_names: Option<Vec<String>>An array of the names of the Amazon Web Services CloudFormation stacks to update. You can specify up to 500 Amazon Web Services CloudFormation stacks.
Implementations
Creates a new builder-style object to manufacture UpdateCloudFormationCollectionFilter