Struct aws_sdk_devopsguru::output::DescribeAccountHealthOutput [−][src]
#[non_exhaustive]pub struct DescribeAccountHealthOutput {
pub open_reactive_insights: i32,
pub open_proactive_insights: i32,
pub metrics_analyzed: i32,
pub resource_hours: Option<i64>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.open_reactive_insights: i32An integer that specifies the number of open reactive insights in your Amazon Web Services account.
open_proactive_insights: i32An integer that specifies the number of open proactive insights in your Amazon Web Services account.
metrics_analyzed: i32An integer that specifies the number of metrics that have been analyzed in your Amazon Web Services account.
resource_hours: Option<i64>The number of Amazon DevOps Guru resource analysis hours billed to the current Amazon Web Services account in the last hour.
Implementations
An integer that specifies the number of open reactive insights in your Amazon Web Services account.
An integer that specifies the number of open proactive insights in your Amazon Web Services account.
An integer that specifies the number of metrics that have been analyzed in your Amazon Web Services account.
The number of Amazon DevOps Guru resource analysis hours billed to the current Amazon Web Services account in the last hour.
Creates a new builder-style object to manufacture DescribeAccountHealthOutput