Struct aws_sdk_devopsguru::output::DescribeAccountOverviewOutput [−][src]
#[non_exhaustive]pub struct DescribeAccountOverviewOutput {
pub reactive_insights: i32,
pub proactive_insights: i32,
pub mean_time_to_recover_in_milliseconds: Option<i64>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reactive_insights: i32An integer that specifies the number of open reactive insights in your AWS account that were created during the time range passed in.
proactive_insights: i32An integer that specifies the number of open proactive insights in your AWS account that were created during the time range passed in.
mean_time_to_recover_in_milliseconds: Option<i64>The Mean Time to Recover (MTTR) for all closed insights that were created during the time range passed in.
Implementations
Creates a new builder-style object to manufacture DescribeAccountOverviewOutput