Struct aws_sdk_devopsguru::output::DescribeOrganizationResourceCollectionHealthOutput [−][src]
#[non_exhaustive]pub struct DescribeOrganizationResourceCollectionHealthOutput {
pub cloud_formation: Option<Vec<CloudFormationHealth>>,
pub service: Option<Vec<ServiceHealth>>,
pub account: Option<Vec<AccountHealth>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cloud_formation: Option<Vec<CloudFormationHealth>>The returned CloudFormationHealthOverview object that contains an
InsightHealthOverview object with the requested system health
information.
service: Option<Vec<ServiceHealth>>An array of ServiceHealth objects that describes the health of the Amazon Web Services
services associated with the resources in the collection.
account: Option<Vec<AccountHealth>>The name of the organization's account.
next_token: Option<String>The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
Implementations
The returned CloudFormationHealthOverview object that contains an
InsightHealthOverview object with the requested system health
information.
An array of ServiceHealth objects that describes the health of the Amazon Web Services
services associated with the resources in the collection.
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
Creates a new builder-style object to manufacture DescribeOrganizationResourceCollectionHealthOutput