Struct aws_sdk_devopsguru::output::DescribeResourceCollectionHealthOutput [−][src]
#[non_exhaustive]pub struct DescribeResourceCollectionHealthOutput {
pub cloud_formation: Option<Vec<CloudFormationHealth>>,
pub service: Option<Vec<ServiceHealth>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cloud_formation: Option<Vec<CloudFormationHealth>>
The returned CloudFormationHealthOverview object that contains an InsightHealthOverview object with
the requested system health information.
service: Option<Vec<ServiceHealth>>An array of ServiceHealth objects that describes the health of the AWS services
associated with the resources in the collection.
next_token: Option<String>The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
Implementations
Creates a new builder-style object to manufacture DescribeResourceCollectionHealthOutput