Struct aws_sdk_devopsguru::output::GetCostEstimationOutput [−][src]
#[non_exhaustive]pub struct GetCostEstimationOutput {
pub resource_collection: Option<CostEstimationResourceCollectionFilter>,
pub status: Option<CostEstimationStatus>,
pub costs: Option<Vec<ServiceResourceCost>>,
pub time_range: Option<CostEstimationTimeRange>,
pub total_cost: f64,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_collection: Option<CostEstimationResourceCollectionFilter>The collection of the Amazon Web Services resources used to create your monthly DevOps Guru cost estimate.
status: Option<CostEstimationStatus>The status of creating this cost estimate. If it's still in progress, the status
ONGOING is returned. If it is finished, the status
COMPLETED is returned.
costs: Option<Vec<ServiceResourceCost>>An array of ResourceCost objects that each contains details about the
monthly cost estimate to analyze one of your Amazon Web Services resources.
time_range: Option<CostEstimationTimeRange>The start and end time of the cost estimation.
total_cost: f64The estimated monthly cost to analyze the Amazon Web Services resources. This value is the sum of
the estimated costs to analyze each resource in the Costs object in this
response.
next_token: Option<String>The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
Implementations
The collection of the Amazon Web Services resources used to create your monthly DevOps Guru cost estimate.
The status of creating this cost estimate. If it's still in progress, the status
ONGOING is returned. If it is finished, the status
COMPLETED is returned.
An array of ResourceCost objects that each contains details about the
monthly cost estimate to analyze one of your Amazon Web Services resources.
The start and end time of the cost estimation.
The estimated monthly cost to analyze the Amazon Web Services resources. This value is the sum of
the estimated costs to analyze each resource in the Costs object in this
response.
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
Creates a new builder-style object to manufacture GetCostEstimationOutput