Struct aws_sdk_devopsguru::model::ResourceCollectionFilter [−][src]
#[non_exhaustive]pub struct ResourceCollectionFilter {
pub cloud_formation: Option<CloudFormationCollectionFilter>,
}Expand description
Information about a filter used to specify which AWS resources are analyzed for anomalous behavior by DevOps Guru.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cloud_formation: Option<CloudFormationCollectionFilter>Information about AWS CloudFormation stacks. You can use up to 500 stacks to specify which AWS resources in your account to analyze. For more information, see Stacks in the AWS CloudFormation User Guide.
Implementations
Creates a new builder-style object to manufacture ResourceCollectionFilter