Struct aws_sdk_devopsguru::output::ListAnomaliesForInsightOutput [−][src]
#[non_exhaustive]pub struct ListAnomaliesForInsightOutput {
pub proactive_anomalies: Option<Vec<ProactiveAnomalySummary>>,
pub reactive_anomalies: Option<Vec<ReactiveAnomalySummary>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.proactive_anomalies: Option<Vec<ProactiveAnomalySummary>>
An array of ProactiveAnomalySummary objects that represent the requested anomalies
reactive_anomalies: Option<Vec<ReactiveAnomalySummary>>
An array of ReactiveAnomalySummary objects that represent the requested anomalies
next_token: Option<String>The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
Implementations
Creates a new builder-style object to manufacture ListAnomaliesForInsightOutput